#include <ESP8266WebServer.h>
#include <FS.h>
#include <WebSocketsServer.h>

ESP8266WebServer server(80);                                          // set up webserver for port 80
WebSocketsServer webSocket = WebSocketsServer(81);                    // set websocket port to 81

// this function executes any time a packet is received over websocket port
void webSocketEvent(uint8_t num, WStype_t type, uint8_t * payload, size_t length) {
  switch (type) {
    case WStype_DISCONNECTED:                                 // if disconnect command
      Serial.printf("[%u] Disconnected!\n", num);
      break;
    case WStype_CONNECTED:                                    // set up when browser javascript connects to websocket port
      {
        IPAddress ip = webSocket.remoteIP(num);
        Serial.printf("[%u] Connected from %d.%d.%d.%d url: %s\n", num, ip[0], ip[1], ip[2], ip[3], payload);
      }
      break;
    case WStype_TEXT:                                       // process packet that is sent as text
      switch (payload[0]) {
        case '1' : digitalWrite(12, HIGH);                  // turn LED 1 on
          webSocket.sendTXT(num, "LED 1 ON");               // send message it is on
          break;

        case '2' : digitalWrite(12, LOW);                  // turn LED 1 off
          webSocket.sendTXT(num, "LED 1 OFF");             // send message it is off
          break;

        case '3' : digitalWrite(13, HIGH);
          webSocket.sendTXT(num, "LED 2 ON");
          break;

        case '4' : digitalWrite(13, LOW);
          webSocket.sendTXT(num, "LED 2 OFF");
          break;
      }
    case WStype_BIN:                                                    // process binary packet, not used
      Serial.printf("[%u] get binary length: %u\n", num, length);
      hexdump(payload, length);
      // send message to client
      // webSocket.sendBIN(num, payload, length);
      break;
  }
}

void setup() {
  Serial.begin(115200);
  pinMode(12, OUTPUT);                                  // LED 1
  pinMode(13, OUTPUT);                                  // LED 2
  SPIFFS.begin();                                       // start file system
  WiFi.mode(WIFI_AP);                                   // set mode to access point
  WiFi.softAP("satellite", "passpasspass");             // setup wifi access point with password
  server.serveStatic("/", SPIFFS, "/index.html");       // link index.html to main page on browser
  server.begin();                                       // start the web server
  webSocket.onEvent(webSocketEvent);                    // link the function to the websocket server
  webSocket.begin();                                    // start the websocket server
}

void loop() {
  webSocket.loop();                               // check if websocket server received a packet
  server.handleClient();                          // check if webserver received a connection
}
